aboutsummaryrefslogtreecommitdiffstats
path: root/src/argparser.h
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2013-06-26 03:13:58 +0200
committerMattias Andrée <maandree@operamail.com>2013-06-26 03:13:58 +0200
commitfad12ccb70f1981ed7269c24d221af66715e3016 (patch)
treedc10344c717968b294b2b8ec59fa5efd159f6839 /src/argparser.h
parentmissed to initialise variable (diff)
downloadargparser-fad12ccb70f1981ed7269c24d221af66715e3016.tar.gz
argparser-fad12ccb70f1981ed7269c24d221af66715e3016.tar.bz2
argparser-fad12ccb70f1981ed7269c24d221af66715e3016.tar.xz
fix varargs
Signed-off-by: Mattias Andrée <maandree@operamail.com>
Diffstat (limited to '')
-rw-r--r--src/argparser.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/argparser.h b/src/argparser.h
index 6df4891..4d6194d 100644
--- a/src/argparser.h
+++ b/src/argparser.h
@@ -181,31 +181,31 @@ extern void args_dispose();
/**
* Creates, but does not add, a option that takes no arguments
*
* @param standard The index of the standard alternative name
* @param count... The alterntive names
* @return The created option
*/
-extern args_Option args_new_argumentless(int standard, int count, ...);
+extern args_Option args_new_argumentless(int standard, char* alternatives, ...);
/**
* Creates, but does not add, a option that takes one argument per use
*
* @param argument The new of the argument
* @param standard The index of the standard alternative name
* @param count... The alterntive names
* @return The created option
*/
-extern args_Option args_new_argumented(char* argument, int standard, int count, ...);
+extern args_Option args_new_argumented(char* argument, int standard, char* alternatives, ...);
/**
* Creates, but does not add, a option that takes all following arguments
*
* @param argument The new of the argument
* @param standard The index of the standard alternative name
* @param count... The alterntive names
* @return The created option
*/
-extern args_Option args_new_variadic(char* argument, int standard, int count, ...);
+extern args_Option args_new_variadic(char* argument, int standard, char* alternatives, ...);
/**
@@ -181,31 +181,31 @@ extern void args_dispose();
* Creates, but does not add, a option that takes no arguments
*
- * @param standard The index of the standard alternative name
- * @param count... The alterntive names
- * @return The created option
+ * @param standard The index of the standard alternative name
+ * @param alternatives... The alterntive names, end with `null`
+ * @return The created option
*/
@@ -181,31 +181,31 @@ extern void args_dispose();
* Creates, but does not add, a option that takes one argument per use
*
- * @param argument The new of the argument
- * @param standard The index of the standard alternative name
- * @param count... The alterntive names
- * @return The created option
+ * @param argument The new of the argument
+ * @param standard The index of the standard alternative name
+ * @param alternatives... The alterntive names, end with `null`
+ * @return The created option
*/
@@ -181,31 +181,31 @@ extern void args_dispose();
* Creates, but does not add, a option that takes all following arguments
*
- * @param argument The new of the argument
- * @param standard The index of the standard alternative name
- * @param count... The alterntive names
- * @return The created option
+ * @param argument The new of the argument
+ * @param standard The index of the standard alternative name
+ * @param alternatives... The alterntive names, end with `null`
+ * @return The created option
*/